==> crm-log-1.3.0.2.release.jar: com/biz/crm/crmlog/handle/tool/One2OneCompare.java <==
package com.biz.crm.crmlog.handle.tool;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.biz.crm.crmlog.template.entity.LogFieldEntity;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.util.Iterator;
import java.util.Map;

/**
 * @Description: 自定义引用类型对比
 * @Author: zhangyuzhu
 * @Date: 2020/12/15 14:42
 **/
public class One2OneCompare {

    /**
     * 比对自定义类型
     * @param fieldMap 模板
     * @param oldJsonObject 改变之前的json
     * @param newJsonObject 改变之后的json
     */
    public static JSONObject compare(Map<String, LogFieldEntity> fieldMap, JSONObject oldJsonObject, JSONObject newJsonObject){
        if(CollectionUtils.isEmpty(fieldMap)){
            return null;
        }
        JSONObject reJson = new JSONObject();
        //循环模板对比
        Iterator iter = fieldMap.entrySet().iterator();
        while (iter.hasNext()) {
            Map.Entry entry = (Map.Entry) iter.next();
            String key = entry.getKey().toString();
            LogFieldEntity subFiledMsg = (LogFieldEntity) entry.getValue();
            Object oldValue = oldJsonObject.get(key);
            Object newValue = newJsonObject.get(key);
            if(subFiledMsg.getHostType() == 0){
                Object obj = BasicTypeCompare.compare(subFiledMsg.getDesc(),oldValue,newValue);
                if(!StringUtils.isEmpty(obj)){
                    reJson.put(subFiledMsg.getDesc(),obj);
                }
            }else if(subFiledMsg.getHostType() == 1){
                Object obj = One2OneCompare.compare(subFiledMsg.getChildren(),
                        (JSONObject)oldValue,
                        (JSONObject)newValue);
                if(!StringUtils.isEmpty(obj)){
                    reJson.put(subFiledMsg.getDesc(),obj);
                }
            }else if(subFiledMsg.getHostType() == 2){
                Object obj = One2ManyConpare.compare(
                        subFiledMsg,
                        JSON.parseArray(JSON.toJSONString(oldValue),JSONObject.class),
                        JSON.parseArray(JSON.toJSONString(newValue),JSONObject.class)
                );
                if(!StringUtils.isEmpty(obj)){
                    reJson.put(subFiledMsg.getDesc(),obj);
                }
            }
        }
        return reJson;
    }
}

==> crm-log-1.3.0.6.20.release.jar: com/biz/crm/crmlog/handle/tool/One2OneCompare.java <==
package com.biz.crm.crmlog.handle.tool;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.biz.crm.crmlog.template.entity.LogFieldEntity;
import com.biz.crm.eunm.YesNoEnum;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.util.Iterator;
import java.util.Map;

/**
 * @Description: 自定义引用类型对比
 * @Author: zhangyuzhu
 * @Date: 2020/12/15 14:42
 **/
public class One2OneCompare {

    /**
     * 比对自定义类型
     * @param fieldMap 模板
     * @param oldJsonObject 改变之前的json
     * @param newJsonObject 改变之后的json
     */
    public static JSONObject compare(Map<String, LogFieldEntity> fieldMap, JSONObject oldJsonObject, JSONObject newJsonObject){
        if(CollectionUtils.isEmpty(fieldMap)){
            return null;
        }
        JSONObject reJson = new JSONObject();
        //循环模板对比
        Iterator iter = fieldMap.entrySet().iterator();
        while (iter.hasNext()) {
            Map.Entry entry = (Map.Entry) iter.next();
            String key = entry.getKey().toString();
            LogFieldEntity subFiledMsg = (LogFieldEntity) entry.getValue();
            //如果不对比 就不用对比
            if(subFiledMsg.getCompareFalg().intValue() == YesNoEnum.YesNoCodeNumberEnum.NO.getCode().intValue()){
                continue;
            }
            Object oldValue = oldJsonObject.get(key);
            Object newValue = newJsonObject.get(key);
            if(subFiledMsg.getHostType() == 0){
                Object obj = BasicTypeCompare.compare(subFiledMsg.getDesc(),oldValue,newValue);
                if(!StringUtils.isEmpty(obj)){
                    reJson.put(subFiledMsg.getDesc(),obj);
                }
            }else if(subFiledMsg.getHostType() == 1){
                Object obj = One2OneCompare.compare(subFiledMsg.getChildren(),
                        (JSONObject)oldValue,
                        (JSONObject)newValue);
                if(!StringUtils.isEmpty(obj)){
                    reJson.put(subFiledMsg.getDesc(),obj);
                }
            }else if(subFiledMsg.getHostType() == 2){
                Object obj = One2ManyConpare.compare(
                        subFiledMsg,
                        JSON.parseArray(JSON.toJSONString(oldValue),JSONObject.class),
                        JSON.parseArray(JSON.toJSONString(newValue),JSONObject.class)
                );
                if(!StringUtils.isEmpty(obj)){
                    reJson.put(subFiledMsg.getDesc(),obj);
                }
            }
        }
        return reJson;
    }
}
